@@ -161,9 +161,7 @@ to_sql.relop_orderby <- function (x,
                                   tnum = mk_tmp_name_source('tsql'),
                                   append_cr = TRUE,
                                   using = NULL) {
-  if(length(list(...))>0) {
-    stop("rquery::to_sql.relop_orderby unexpected arguments")
-  }
+  wrapr::stop_if_dot_args(substitute(list(...)), "rquery::to_sql.relop_orderby")
   dispatch_to_sql_method(
     method_name = "to_sql.relop_orderby",
     x = x,
